==> xlog-spring-boot-1.1.13-20241208.033421-10-sources.jar: com/xforceplus/xlog/springboot/autoconfiguration/standalone/XlogStandaloneConsumerConfiguration2.java <==
package com.xforceplus.xlog.springboot.autoconfiguration.standalone;

import com.xforceplus.apollo.janus.standalone.sdk.annotation.GlobalEventListener;
import com.xforceplus.xlog.logsender.model.LogSender;
import com.xforceplus.xlog.springboot.autoconfiguration.XlogAutoConfiguration;
import com.xforceplus.xlog.springboot.autoconfiguration.model.XlogProperties;
import com.xforceplus.xlog.standalone.model.StandaloneConsumerInterceptor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.boot.autoconfigure.AutoConfigureAfter;
import org.springframework.boot.autoconfigure.condition.ConditionalOnClass;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

@Slf4j
@Configuration
@AutoConfigureAfter(XlogAutoConfiguration.class)
@ConditionalOnClass({GlobalEventListener.class})
@ConditionalOnProperty(prefix = "xlog", name = {"enabled", "standalone.consumer.enabled"}, havingValue = "true")
public class XlogStandaloneConsumerConfiguration2 {
    private final XlogProperties xlogProperties;

    public XlogStandaloneConsumerConfiguration2(final XlogProperties xlogProperties) {
        this.xlogProperties = xlogProperties;
    }

    @Bean
    @ConditionalOnMissingBean
    public XlogStandaloneConsumerAdvice2 xlogStandaloneConsumerAdvice2(final LogSender logSender) {
        log.info(String.format("xlog.standalone.consumer2已尝试启动... 参数: %s", this.xlogProperties.getStandalone()));
        return new XlogStandaloneConsumerAdvice2(new StandaloneConsumerInterceptor(logSender, this.xlogProperties.getStoreName()));
    }

    @Bean
    @ConditionalOnMissingBean
    public XlogStandaloneConsumerBeanPostProcessor xlogStandaloneConsumerBeanPostProcessor() {
        return new XlogStandaloneConsumerBeanPostProcessor();
    }
}

==> xlog-spring-boot-1.1.14-20250218.010157-7-sources.jar: com/xforceplus/xlog/springboot/autoconfiguration/standalone/XlogStandaloneConsumerConfiguration2.java <==
package com.xforceplus.xlog.springboot.autoconfiguration.standalone;

import com.xforceplus.apollo.janus.standalone.sdk.annotation.GlobalEventListener;
import com.xforceplus.xlog.core.model.setting.XlogSettings;
import com.xforceplus.xlog.core.model.setting.XlogStandaloneConsumerSettings;
import com.xforceplus.xlog.core.model.setting.XlogStandaloneSettings;
import com.xforceplus.xlog.logsender.model.LogSender;
import com.xforceplus.xlog.springboot.autoconfiguration.XlogAutoConfiguration;
import com.xforceplus.xlog.springboot.autoconfiguration.model.XlogProperties;
import com.xforceplus.xlog.standalone.model.StandaloneConsumerInterceptor;
import java.util.Optional;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.AutoConfigureAfter;
import org.springframework.boot.autoconfigure.condition.ConditionalOnClass;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

@Slf4j
@Configuration
@AutoConfigureAfter(XlogAutoConfiguration.class)
@ConditionalOnClass({GlobalEventListener.class})
@ConditionalOnProperty(prefix = "xlog", name = {"enabled", "standalone.consumer.enabled"}, havingValue = "true")
public class XlogStandaloneConsumerConfiguration2 {
    private final XlogProperties xlogProperties;

    public XlogStandaloneConsumerConfiguration2(final XlogProperties xlogProperties) {
        this.xlogProperties = xlogProperties;
    }

    @Bean
    @ConditionalOnMissingBean
    public XlogStandaloneConsumerAdvice2 xlogStandaloneConsumerAdvice2(final LogSender logSender,final @Autowired(required = false) XlogSettings xlogSettings) {
        log.info(String.format("xlog.standalone.consumer2已尝试启动... 参数: %s", this.xlogProperties.getStandalone()));
        final XlogStandaloneSettings xlogStandaloneSettings = Optional.ofNullable(xlogSettings)
                                                                      .map(XlogSettings::getStandalone)
                                                                      .orElse(null);
        return new XlogStandaloneConsumerAdvice2(new StandaloneConsumerInterceptor(logSender, this.xlogProperties.getStoreName(),xlogStandaloneSettings));
    }

    @Bean
    @ConditionalOnMissingBean
    public XlogStandaloneConsumerBeanPostProcessor xlogStandaloneConsumerBeanPostProcessor() {
        return new XlogStandaloneConsumerBeanPostProcessor();
    }
}
